maxLevel property
The maximum indentation level allowed for tree nodes.
This value can be used to limit the indentation of tree nodes. If a node expands to a level higher than maxLevel, all descendants will have the same indentation level as their parent.
Defaults to largestPositiveInteger.
Implementation
final int maxLevel;