PathModifier typedef

PathModifier = Path Function(Path path)

Signature for a function that takes a Path and returns a Path.

Used by the tree line painters to update the tree line path if desired.

Implementation

typedef PathModifier = Path Function(Path path);